summaryrefslogtreecommitdiff
path: root/src/mongo/db/repl/repl_set_request_votes_args.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/repl/repl_set_request_votes_args.h')
-rw-r--r--src/mongo/db/repl/repl_set_request_votes_args.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/repl/repl_set_request_votes_args.h b/src/mongo/db/repl/repl_set_request_votes_args.h
index 12541650798..7f1cf3bc72e 100644
--- a/src/mongo/db/repl/repl_set_request_votes_args.h
+++ b/src/mongo/db/repl/repl_set_request_votes_args.h
@@ -46,7 +46,7 @@ public:
long long getTerm() const;
long long getCandidateIndex() const;
long long getConfigVersion() const;
- OpTime getLastCommittedOp() const;
+ OpTime getLastDurableOpTime() const;
bool isADryRun() const;
void addToBSON(BSONObjBuilder* builder) const;
@@ -56,9 +56,9 @@ private:
long long _term = -1; // Current known term of the command issuer.
// replSet config index of the member who sent the replSetRequestVotesCmd.
long long _candidateIndex = -1;
- long long _cfgver = -1; // replSet config version known to the command issuer.
- OpTime _lastCommittedOp; // The last known committed op of the command issuer.
- bool _dryRun = false; // Indicates this is a pre-election check when true.
+ long long _cfgver = -1; // replSet config version known to the command issuer.
+ OpTime _lastDurableOpTime; // The last known durable op of the command issuer.
+ bool _dryRun = false; // Indicates this is a pre-election check when true.
};
class ReplSetRequestVotesResponse {